package com.teamchat.sdk.sample;

import android.content.Context;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;


import com.webaroo.teamchatsdk.sdk.Teamchat;
import com.webaroo.teamchatsdk.sdk.TeamchatError;
import com.webaroo.teamchatsdk.sdk.TeamchatGroupCreator;

import java.util.ArrayList;

public class RoomList extends AppCompatActivity {

    private ArrayList<Teamchat.TeamchatGroup> mGroups;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_room_list);
        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        setTitle("TestApp");
        loadRooms();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_room_list, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        } else if(id == android.R.id.home){
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    private void loadRooms() {
        Teamchat.teamChatGroups(new Teamchat.TeamchatGroupsLoaded() {
            @Override
            public void onTeamchatGroupsLoaded(boolean suc, ArrayList<Teamchat.TeamchatGroup> groups, String error) {
                if (suc) {
                    Log.d("Teamchat", "__________no of groups : " + groups.size());
                    mGroups = groups;
                    populateRoomsList(mGroups);
                } else
                    Log.d("Teamchat", "__________no of groups : " + error);
            }
        }, this);
    }

    private void populateRoomsList(ArrayList<Teamchat.TeamchatGroup> groups) {
        ListView roomslist = (ListView) findViewById(R.id.room_listview);
        roomslist.setAdapter(new CustomAdapter(groups, this));
    }

    public static class ViewHolder {

        public TextView groupName;
        public TextView groupId;
        public Button addMembers, showRoom;

    }

    class CustomAdapter extends BaseAdapter {
        private final LayoutInflater inflater;
        ArrayList<Teamchat.TeamchatGroup> mGrous;

        CustomAdapter(ArrayList<Teamchat.TeamchatGroup> groups, Context context) {
            mGrous = groups;
            inflater = (LayoutInflater)context.
                    getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        }

        @Override
        public int getCount() {
            return mGrous.size();
        }

        @Override
        public Object getItem(int position) {
            return null;
        }

        @Override
        public long getItemId(int position) {
            return 0;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            ViewHolder holder;
            View vi = convertView;
            if (convertView == null) {
                vi = inflater.inflate(R.layout.group_list_item, null);
                holder = new ViewHolder();
                holder.groupId = (TextView) vi.findViewById(R.id.group_id);
                holder.groupName = (TextView) vi.findViewById(R.id.group_name);
                holder.addMembers = (Button) vi.findViewById(R.id.add_members);
                holder.showRoom = (Button) vi.findViewById(R.id.show_room);
                vi.setTag(holder);
            } else
                holder = (ViewHolder) convertView.getTag();
            final Teamchat.TeamchatGroup group = mGrous.get(position);
            holder.groupName.setText(group.getGroupName());
            holder.groupId.setText("ID: "+group.getGroupID());
            holder.showRoom.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    Teamchat.openRoom(group.getGroupID(), RoomList.this);
                }
            });
            holder.addMembers.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    ArrayList<Teamchat.TCTeamchatContact> membersToBeAdded = new ArrayList<>();
                    Teamchat.TCTeamchatContact contact1 = new Teamchat.TCTeamchatContact();
                    contact1.email = "uvw@gmail.com";
                    contact1.profileName = "uvw";

                    Teamchat.TCTeamchatContact contact2 = new Teamchat.TCTeamchatContact();
                    contact2.email = "xyz@gmail.com";
                    contact2.profileName = "xyz";

                    Teamchat.TCTeamchatContact contact3 = new Teamchat.TCTeamchatContact();
                    contact3.phone = "0123456789";
                    contact3.profileName = "uvw";

                    Teamchat.TCTeamchatContact contact4 = new Teamchat.TCTeamchatContact();
                    contact4.phone = "1234567890";
                    contact4.profileName = "xyz";

                    Teamchat.TCTeamchatContact contact5 = new Teamchat.TCTeamchatContact();
                    contact5.email = "vishwesh.joshi@robosoftin.com";
                    contact5.phone = "2345678901";
                    contact5.profileName = "vishwesh";

                    Teamchat.TCTeamchatContact contact6 = new Teamchat.TCTeamchatContact();
                    contact6.email = "vidyalaxmiv.shenoy@robosoftin.com";
                    contact6.phone = "3456789012";
                    contact6.profileName = "vidya laxmi";

                    membersToBeAdded.add(contact1);
                    membersToBeAdded.add(contact2);
                    membersToBeAdded.add(contact3);
                    membersToBeAdded.add(contact4);
                    membersToBeAdded.add(contact5);
                    membersToBeAdded.add(contact6);

                    TeamchatGroupCreator.addMembers(getBaseContext(), membersToBeAdded, group, new TeamchatGroupCreator.TeamchatGroupOperationCompletionHandler() {
                        @Override
                        public void onTeamchatGroupOperationComplete(boolean success, TeamchatError error, String message) {
                            if(success)
                                Toast.makeText(getBaseContext(), "Members added successfully.", Toast.LENGTH_LONG).show();
                            else
                            {
                                String errorMessage = "";
                                if(error != null)
                                    errorMessage = error.getErrorMessage();
                                Toast.makeText(getBaseContext(), "Failed adding members. " + errorMessage, Toast.LENGTH_LONG).show();
                            }
                        }
                    });
                }
            });
            return vi;
        }
    }
}
